@@ -9,12 +9,12 @@
 # @examples \\dontrun{}
 # @author Fabian E. Bachl <\email{f.e.bachl@@bath.ac.uk}>
 
-covariate = function(data, predictor = NULL, mesh = NULL){
-  if ( inherits(data, "SpatialPointsDataFrame") ) {
-
-    cv = covdata.import(as.data.frame(data), 
-                        deparse(substitute(predictor)), 
-                        data = list(mesh = mesh, mesh.coords = coordnames(data)))
+covariate <- function(data, predictor = NULL, mesh = NULL) {
+  if (inherits(data, "SpatialPointsDataFrame")) {
+    cv <- covdata.import(as.data.frame(data),
+      deparse(substitute(predictor)),
+      data = list(mesh = mesh, mesh.coords = coordnames(data))
+    )
     cv
   }
 }
@@ -29,16 +29,20 @@ covariate = function(data, predictor = NULL, mesh = NULL){
 # @examples \\dontrun{}
 # @author Fabian E. Bachl <\email{f.e.bachl@@bath.ac.uk}>
 
-evaluator = function(cdata, method = NULL, ...){
-  
-  if ( class(cdata)[1] == "covdata") { 
-    if ( is.null(method) ) { method = get.value }
-    return( function(...){ method(cdata, data.frame(...)) } )
-  }  
-  
-  else if (class(cdata)[1] == "SpatialPolygonsDataFrame") {
-    if ( is.null(method) ) { method = shapefile.to.covariate }
-    return( method(cdata, ...) )
+evaluator <- function(cdata, method = NULL, ...) {
+  if (class(cdata)[1] == "covdata") {
+    if (is.null(method)) {
+      method <- get.value
+    }
+    return(function(...) {
+      method(cdata, data.frame(...))
+    })
   }
-  
-}
\ No newline at end of file
+
+  else if (class(cdata)[1] == "SpatialPolygonsDataFrame") {
+    if (is.null(method)) {
+      method <- shapefile.to.covariate
+    }
+    return(method(cdata, ...))
+  }
+}
