@@ -1,5 +1,5 @@
 \donttest{
-if (bru_safe_inla()) {
+if (bru_safe_inla(multicore = FALSE)) {
 
   # Load the Gorilla data
 
